@@ -23,7 +23,7 @@ use WebService::DMM::Series;
 
 use utf8;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 my $agent_name = __PACKAGE__ . "/$VERSION";
 our $UserAgent = Furl->new(agent => $agent_name);
@@ -558,7 +558,7 @@ Number of items
 
 =item offset :Int = 1
 
-Number of page
+Offset of searched results
 
 =item sort :Str = "rank"
 
